// Copyright © 2025 Advanced Micro Devices, Inc.
// SPDX-License-Identifier: MIT

// clang-format off
#pragma once

#include <aotriton/config.h>
#include <aotriton/dtypes.h>
#include <aotriton/util.h>
#include <aotriton/runtime.h>
#include <aotriton/_internal/lazy_tensor_internal.h>
#include <aotriton/flash.h>
#include <functional>
#include <string>
#include <vector>

namespace AOTRITON_NS::v3::flash {

// Unlike KernelDescription, Operator must have its own parameter class
struct OpAttnBwdParams {
    const TensorView<4>*   Q;
    const TensorView<4>*   K;
    const TensorView<4>*   V;
    const TensorView<4>*   B;
    float                  sm_scale;
    const TensorView<4>*   Out;
    const TensorView<4>*   DO;
    const TensorView<4>*   DK;
    const TensorView<4>*   DV;
    const TensorView<4>*   DQ;
    const TensorView<4>*   DB;
    LazyTensorInternal<4>* DQ_ACC;
    const TensorView<2>*   L;
    LazyTensorInternal<2>* D;
    int32_t                num_head_q;
    int32_t                num_head_k;
    const TensorView<1>*   cu_seqlens_q;
    const TensorView<1>*   cu_seqlens_k;
    int32_t                num_seqlens;
    int32_t                max_seqlen_q;
    int32_t                max_seqlen_k;
    const TensorView<1>*   seq_strides_q;
    const TensorView<1>*   seq_strides_k;
    int32_t                hdim_qk;
    int32_t                hdim_vo;
    float                  dropout_p;
    const TensorView<0>*   philox_seed_ptr;
    const TensorView<0>*   philox_offset1;
    uint64_t               philox_offset2;
    int32_t                Window_left;
    int32_t                Window_right;
    int16_t                BLOCK_DMODEL;
    int8_t                 CAUSAL_TYPE;
    bool                   ENABLE_DROPOUT;
    bool                   PADDED_HEAD;
    int8_t                 BIAS_TYPE;
};

struct OpAttnBwdContext {
    OpAttnBwdParams *params = nullptr;
    const attn_options *call_options = nullptr;
    enum BackendEnum : int32_t {
        None = -1,
        kMetro_TritonSplit = 0,
        kShim_BwdKernelFuse = 1,
        kSlimAffine_AiterFmhaV3Bwd = 2,
        Max = 3
    };
    static constexpr BackendEnum fallback_backend = kMetro_TritonSplit;
    BackendEnum backend_index = BackendEnum::None;
    bool disable_fallback = false;

#if AOTRITON_BUILD_FOR_TUNING
    int _has_preferred_backend = -1;
    static constexpr int _total_number_of_backends = BackendEnum::Max;
    const char* _backend_name = nullptr;
#endif

    // One more layer of dispatcher of functionals is added due to
    // 1. Individual kernel may use fewer arguments
    // 2. Metro kernel needs overall performance numbers over individual kernels.
    // 3. Even metro kernel only has one kernel, another set LUT is need to
    //    determine which metro kernel (or backend) need to be used
    int64_t godel_number() const;
    // get_archmod_number must be implemented in per-kernel/op basis
    // because different kernel/op may have different sets of GPU supported,
    // e.g., vector_add can be supported by all GPUs but SDPA can only be
    // supported on GPUs with WGMMA/MFMA/WMMA
    static std::tuple<int, int> get_archmod_number(Gpu gpu);
    static constexpr int kMaxGodelNumber = 576;

    hipError_t lookup_optimal(Gpu gpu);
    // Unlike Triton kernel, Operator's launch need gpu argument to eventually
    // call backend's lookup_optimal
    hipError_t launch(Gpu gpu, hipStream_t stream) const;
private:
    // Returns the selected backend_index (-1 when no valid backend was selected).
    typedef int (*OpTuneTableEntry)(OpAttnBwdContext& context, int mod_number);
    static OpTuneTableEntry optune_table[][ kMaxGodelNumber ];

    typedef hipError_t (*BackendLauncher)(const OpAttnBwdContext& context,
                                          Gpu gpu,
                                          hipStream_t stream);
    static BackendLauncher launcher_table[ BackendEnum::Max ];
};

namespace optune {

extern int op_attn_bwd__lut_lambda__0(const OpAttnBwdParams& params, int mod_number, int8_t lut[1][10][10]);
extern int op_attn_bwd__lut_lambda__1(const OpAttnBwdParams& params, int mod_number, int8_t lut[1][8][8]);

int Optune_op_attn_bwd__A0__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F220(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A0__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A1__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A2__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A3__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A4__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A5__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A6__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A7__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A8__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F1(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F17(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F193(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F209(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F220(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F560(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F561(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F564(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A9__F565(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F0(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F1(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F4(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F5(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F8(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F12(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F16(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F17(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F20(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F21(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F24(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F28(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F32(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F33(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F36(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F37(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F40(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F44(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F48(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F49(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F52(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F53(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F56(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F60(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F64(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F65(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F68(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F69(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F72(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F76(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F80(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F81(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F84(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F85(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F88(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F92(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F96(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F97(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F100(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F101(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F104(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F108(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F112(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F113(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F116(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F117(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F120(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F124(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F128(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F129(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F132(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F133(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F136(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F140(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F144(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F145(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F148(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F149(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F152(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F156(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F160(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F161(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F164(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F165(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F168(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F172(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F192(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F193(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F196(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F197(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F200(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F204(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F208(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F209(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F212(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F213(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F216(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F220(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F224(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F225(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F228(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F229(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F232(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F236(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F240(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F241(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F244(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F245(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F248(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F252(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F256(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F257(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F260(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F261(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F264(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F268(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F272(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F273(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F276(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F277(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F280(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F284(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F288(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F289(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F292(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F293(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F296(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F300(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F304(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F305(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F308(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F309(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F312(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F316(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F320(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F321(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F324(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F325(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F328(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F332(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F336(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F337(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F340(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F341(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F344(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F348(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F352(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F353(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F356(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F357(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F360(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F364(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F384(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F385(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F388(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F389(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F392(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F396(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F400(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F401(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F404(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F405(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F408(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F412(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F416(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F417(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F420(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F421(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F424(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F428(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F432(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F433(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F436(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F437(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F440(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F444(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F448(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F449(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F452(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F453(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F456(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F460(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F464(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F465(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F468(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F469(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F472(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F476(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F480(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F481(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F484(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F485(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F488(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F492(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F496(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F497(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F500(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F501(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F504(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F508(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F512(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F513(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F516(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F517(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F520(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F524(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F528(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F529(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F532(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F533(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F536(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F540(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F544(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F545(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F548(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F549(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F552(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F556(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F560(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F561(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F564(OpAttnBwdContext& params, int mod_number);
int Optune_op_attn_bwd__A10__F565(OpAttnBwdContext& params, int mod_number);

}

}

// vim: set fileencoding=utf-8

